@@ -28,6 +28,7 @@ Or:
         -host=>"lamachine",    
         -user=>"bozo",
         -rmtopts=>"-type UNIX -prefix appname",
+        -rmtenv=>"PERL5LIB=/lib/foo FOO=bar",
         -date=>"parsed", -yrfmt=>4, -monthdir=>"../..",
         -timeout=>999,
         -request_timeout=>999,
@@ -45,7 +46,13 @@ See WatchFile for detailed description of options.
 
 =head1 DESCRIPTION
 
-The File::SmartTail module provides functionality modeled on the UNIX tail command, but enhanced with a variety of options, and the capability to "remember" how far it has processed a file, between invocations. rtail.pl is not normally used directly, but is invoked by a File::SmartTail object when monitoring a file on a remote host. When monitoring files on a remote machine, rtail.pl must be in the path of the owner of the process, on the remote machine. Normally it is installed in /usr/local/bin. 
+The File::SmartTail module provides functionality modeled on the UNIX tail
+command, but enhanced with a variety of options, and the capability to
+"remember" how far it has processed a file, between invocations. rtail.pl is
+not normally used directly, but is invoked by a File::SmartTail object when
+monitoring a file on a remote host. When monitoring files on a remote machine,
+rtail.pl must be in the path of the owner of the process, on the remote machine.
+Normally it is installed in /usr/local/bin. 
 
 =head1 AUTHOR
 
@@ -53,10 +60,10 @@ DMJA, Inc <smarttail@dmja.com>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2003-2008 DMJA, Inc, File::SmartTail comes with 
+Copyright (C) 2003-2015 DMJA, Inc, File::SmartTail comes with 
 ABSOLUTELY NO WARRANTY. This is free software, and you are welcome to 
 redistribute it and/or modify it under the same terms as Perl itself.
-See the "The Artistic License" L<perlartistic> for more details.
+See the "The Artistic License" L<LICENSE> for more details.
 
 =cut
 
@@ -64,8 +71,6 @@ package File::SmartTail;
 
 use strict;
 use vars qw( $VERSION );
-use DB_File;
-use NDBM_File;
 use Fcntl;
 use File::Basename;
 use IO::Seekable;
@@ -106,10 +111,8 @@ or
 
     $tail = new File::SmartTail(-tietype=>$type, -statuskey=>$programname, -bindir=>$rtail_script_location, $filename1, $filename2, ...)
 
-Supported tietypes:
-
-    NDBM_File
-    DB_File
+B<i-tietype> can be any class that can be tied to a hash like NDBM_File DB_File
+SDBM_File.
 
 Default statuskey is name of invoking program.
 
@@ -130,7 +133,11 @@ sub new {
     @args{ @_ } = ();
     my %h = @_;
     if ( exists $h{-tietype} ) {
-        $h{-tietype} && $h{-tietype} =~ /NDBM/ and $TIETYPE = 'NDBM_File';
+        if ($h{-tietype} =~ /NDBM/) {
+            $TIETYPE = 'NDBM_File';
+        } else {
+            $TIETYPE = $h{-tietype};
+        }
         delete @args{ '-tietype', $h{-tietype} };
     }
     if ( exists $h{-statuskey} ) {
@@ -510,6 +517,11 @@ Required for type "UNIX-REMOTE" unless file name is of the form host:filename (s
 
 Any flags that should be passed to the remote process. Since these become command-line args, they should have the form "-opt1 val1 -opt2 val2 ...". 
 
+=item -rmtenv=>"ENV1=val1 ENV1=val2"
+
+Any environment variables that should be set on the remote before runnign the
+remote process.
+
 =item -date=>'parsed' or 'gz'
     
 indicates special date-related file
@@ -615,6 +627,7 @@ sub OpenRemote {
     my $filename = $opts{-current};
     my $hostname = $opts{-host};
     my $prefix = $opts{-prefix};
+    my $rmtenv;
     my $ssh = $opts{-rmtsh} || $self->{file_data}->{$key}->{opts}->{-rmtsh} || "ssh";
     my ($conn_try, $port, $port_try, $ssh_try, $sock, $tmpfile);
 
@@ -629,6 +642,10 @@ sub OpenRemote {
 	return undef;
     }
 
+
+    if ($opts{-rmtenv}) {
+        $rmtenv = "/usr/bin/env $opts{-rmtenv}";
+    }
     #
     # Set the filestatus file prefix for the remote process
     # (if it isn't set already).
@@ -666,7 +683,7 @@ sub OpenRemote {
     my $fallback_ssh = 0;
     RSHELL: {
 	$tmpfile = new IO::File;
-	my $cmd = "$ssh $hostname -n $userflag $self->{BINDIR}rtail.pl -file $filename $rmtopts |";
+	my $cmd = "$ssh $hostname -n $userflag $rmtenv $self->{BINDIR}rtail.pl -file $filename $rmtopts < /dev/null |";
         LOG()->debug( qq( Preparing to open "$cmd") );
 	unless ($self->{file_data}->{$key}->{child} = $tmpfile->open($cmd)) {
 	    warn "Attempt $ssh_try to open of $ssh pipe for $key failed [$!]  , child status [$?]\n";
